import NotebookAdapter from './NotebookAdapter';
import { ReactPortal } from 'react';
import { INotebookModel } from '@jupyterlab/notebook';
import * as nbformat from '@jupyterlab/nbformat';
import { Cell, ICellModel } from '@jupyterlab/cells';
import { NotebookChange } from '@jupyter/ydoc';
import { Kernel as JupyterKernel } from '@jupyterlab/services';
import Kernel from '../../jupyter/kernel/Kernel';
export type PortalDisplay = {
    portal: ReactPortal;
    pinned: boolean;
};
export type INotebookState = {
    model?: INotebookModel;
    adapter?: NotebookAdapter;
    saveRequest?: Date;
    activeCell?: Cell<ICellModel>;
    kernelStatus?: JupyterKernel.Status;
    notebookChange?: NotebookChange;
    portals: ReactPortal[];
    portalDisplay?: PortalDisplay;
};
export interface INotebooksState {
    notebooks: Map<string, INotebookState>;
}
type UpdateUid = {
    uid: string;
    partialState: Partial<INotebookState>;
};
type NotebookChangeUid = {
    uid: string;
    notebookChange: NotebookChange;
};
type NotebookModelUid = {
    uid: string;
    notebookModel: INotebookModel;
};
type CellModelUid = {
    uid: string;
    cellModel?: Cell<ICellModel>;
};
type KernelStatusMutation = {
    uid: string;
    kernelStatus: JupyterKernel.Status;
};
type KernelChangeMutation = {
    uid: string;
    kernel: Kernel;
};
type ReactPortalsMutation = {
    uid: string;
    portals: ReactPortal[];
};
type PortalDisplayMutation = {
    uid: string;
    portalDisplay: PortalDisplay | undefined;
};
type DateMutation = {
    uid: string;
    date: Date | undefined;
};
type CellMutation = {
    uid: string;
    cellType: nbformat.CellType;
    source?: string;
};
export type NotebookState = INotebooksState & {
    setNotebooks: (notebooks: Map<string, INotebookState>) => void;
    selectNotebook: (uid: string) => INotebookState | undefined;
    selectNotebookModel: (uid: string) => {
        model: INotebookModel | undefined;
        changed: any;
    } | undefined;
    selectKernelStatus: (uid: string) => string | undefined;
    selectActiveCell: (uid: string) => Cell<ICellModel> | undefined;
    selectNotebookPortals: (uid: string) => React.ReactPortal[] | undefined;
    selectSaveRequest: (uid: string) => Date | undefined;
    selectNotebookPortalDisplay: (uid: string) => PortalDisplay | undefined;
    run: (uid: string) => void;
    runAll: (uid: string) => void;
    interrupt: (uid: string) => void;
    insertAbove: (mutation: CellMutation) => void;
    insertBelow: (mutation: CellMutation) => void;
    delete: (uid: string) => void;
    changeCellType: (mutation: CellMutation) => void;
    save: (mutation: DateMutation) => void;
    reset: () => void;
    update: (update: UpdateUid) => void;
    activeCellChange: (cellModelUid: CellModelUid) => void;
    modelChange: (notebookModelUid: NotebookModelUid) => void;
    notebookChange: (notebookChangeUid: NotebookChangeUid) => void;
    kernelStatusChanged: (kernelStatusUid: KernelStatusMutation) => void;
    changeKernel: (kernelChange: KernelChangeMutation) => void;
    addPortals: (portalsUid: ReactPortalsMutation) => void;
    dispose: (uid: string) => void;
    setPortals: (portalsUid: ReactPortalsMutation) => void;
    setPortalDisplay: (portalDisplayUid: PortalDisplayMutation) => void;
};
export declare const notebookStore: import("zustand").StoreApi<NotebookState>;
export declare function useNotebookStore(): NotebookState;
export declare function useNotebookStore<T>(selector: (state: NotebookState) => T): T;
export default useNotebookStore;
