/*
 * Copyright (c) 2021-2023 Datalayer, Inc.
 *
 * MIT License
 */
import { createStore } from 'zustand/vanilla';
import { useStore } from 'zustand';
export const outputStore = createStore((set, get) => ({
    outputs: new Map(),
    setOutputs: (outputs) => set((state) => ({ outputs })),
    setAdapter: (id, adapter) => {
        const outputs = get().outputs;
        const d = outputs.get(id);
        if (d) {
            d.adapter = adapter;
        }
        else {
            outputs.set(id, { adapter });
        }
        set((state) => ({ outputs }));
    },
    setDataset: (dataset) => {
        const sourceId = dataset.sourceId;
        const outputs = get().outputs;
        const d = outputs.get(sourceId);
        if (d) {
            d.dataset = dataset;
        }
        else {
            outputs.set(sourceId, { dataset });
        }
        set((state) => ({ outputs }));
    },
    setExecute: (execute) => {
        const sourceId = execute.sourceId;
        const outputs = get().outputs;
        const e = outputs.get(sourceId);
        if (e) {
            e.execute = execute;
        }
        else {
            outputs.set(sourceId, { execute });
        }
        set((state) => ({ outputs }));
    },
    setSource: (setSource) => {
        const sourceId = setSource.sourceId;
        const outputs = get().outputs;
        const s = outputs.get(sourceId);
        if (s) {
            s.setSource = setSource;
        }
        else {
            outputs.set(sourceId, { setSource });
        }
        set((state) => ({ outputs }));
    },
    setGrade: (grade) => {
        const sourceId = grade.sourceId;
        const outputs = get().outputs;
        const g = outputs.get(sourceId);
        if (g) {
            g.grade = grade;
        }
        else {
            outputs.set(sourceId, { grade });
        }
        set((state) => ({ outputs }));
    },
    getAdapter: (id) => {
        return get().outputs.get(id)?.adapter;
    },
    getSource: (id) => {
        return get().outputs.get(id)?.source;
    },
    getDataset: (id) => {
        return get().outputs.get(id)?.dataset;
    },
    getExecute: (id) => {
        return get().outputs.get(id)?.execute;
    },
    getGrade: (id) => {
        return get().outputs.get(id)?.grade;
    },
}));
export function useOutputStore(selector) {
    return useStore(outputStore, selector);
}
export default useOutputStore;
//# sourceMappingURL=OutputState.js.map